Skip to contents

This function constructs a spacer guide primitive. The spacer is intended for use in guide composition.

Usage

primitive_spacer(
  space = NULL,
  title = waiver(),
  theme = NULL,
  position = waiver()
)

Arguments

space

A [<unit[1]>][grid::unit()]

title

One of the following to indicate the title of the guide:

  • A <character[1]> or <expression[1]> to set a custom title.

  • NULL to not display any title.

  • waiver() (default) to take the name of the scale object or the name specified in labs() as the title.

theme

A <theme> object to style the guide individually or differently from the plot's theme settings. The theme argument in the guide overrides and is combined with the plot's theme.

position

A <character[1]> giving the location of the guide. Can be one of "top", "bottom", "left" or "right".

Value

A <PrimitiveSpacer> primitive guide that can be used inside other guides.

Details

Styling options

Below are the theme options that determine the styling of this guide. In context to many primitive guides, whether it is used in an axis or legend has no bearing on the style.

Theme settingContextTypeDescription
legendry.guide.spacingAnyunit()Fallback amount of spacing when the space argument is NULL

There are no other styling options. The context-agnostic alternative to using theme() is to use theme_guide():

primitive_spacer(theme = theme_guide(
  spacing = unit(5, "mm"),
))

Examples

ggplot(mpg, aes(displ, hwy)) +
  geom_point() +
  guides(
    x = guide_axis_stack("axis", primitive_spacer(unit(1, "cm")), "axis")
  )